alabaster: Default theme for the Sphinx documentation system
============================================================

Description
-----------

Alabaster is a visually (c)lean, responsive, configurable theme for the
Sphinx documentation system. It is Python 2+3 compatible.

It began as a third-party theme, and is still maintained separately, but
as of Sphinx 1.3, Alabaster is an install-time dependency of Sphinx and
is selected as the default theme.

Live examples of this theme can be seen on paramiko.org, fabfile.org and
pyinvoke.org.

Upstream Contact
----------------

https://alabaster.readthedocs.io/en/latest/
